# greentea
A microframework for abstraction. 

## Build status
[![CircleCI](https://circleci.com/gh/nryotaro/greentea/tree/master.svg?style=svg)](https://circleci.com/gh/nryotaro/greentea/tree/master)

## Documentations

- [3.0.2](https://nryotaro.dev/greentea/3.0.2/)
- [3.0.0](https://nryotaro.dev/greentea/3.0.0/)
- [2.0.0](https://nryotaro.dev/greentea/2.0.0/)
